• Home
  • Blog
  • Add-ons
  • Forum
  • Wiki
  • Developers
Nightingale - The tune of life, the tune of yours
  • Portal
  • Search
  • Member List
  • Calendar
  • Help
  • Portal
  • Search
  • Member List
  • Calendar
  • Help
Guest Hi, Guest
  • Login
  • Register
Login
Username:
Password: Lost Password?
 
Nightingale Forums Development Technical Development Library order?

Poll: Would you prefer albums ordered alphabetically or by release date?
Alphabetically
Release Date
[Show Results]
 
Note: This is a public poll, other users will be able to see what you voted for.
Pages (2): 1 2 Next »
Thread Rating:
  • 0 Vote(s) - 0 Average
  • 1
  • 2
  • 3
  • 4
  • 5
Thread Modes
Library order?
Ezekiel000 Offline
Moderator
*****
Posts: 100
Threads: 5
Joined: Sep 2010
Reputation: 2
#1
12-21-2010, 09:41 AM
Currently the Songbird library is sorted like this:
Artist (A-Z) -> Album (A-Z) -> Disc Number -> Track Number -> Track Name
I proposed that it be changed to:
Artist (A-Z) -> Release Date -> Album (A-Z) -> Disc Number -> Track Number -> Track Name

This would mean that your library is order with albums under artist in release order rather than alphabetical.
With Vorbis Ogg you wouldn't really need the "Album (A-Z)" as you can add the full release date not just the year (Which is currently not supported in Songbird)
I reported this to the Songbird team but they seem to not even want to consider this sort of change. What about in Nightingale will we see this sort of thing? (and support for full release dates for Vorbis Ogg)
See bug report here: http://bugzilla.songbirdnest.com/show_bug.cgi?id=23052
Find
Reply
Matt-SD Offline
Administrator
*******
Posts: 53
Threads: 4
Joined: Sep 2010
Reputation: 0
#2
12-21-2010, 10:13 AM
I like it.
... and that's how I killed my neighbours cat.

http://mattsd.com/
Website Find
Reply
Methos Offline
Junior Member
**
Posts: 8
Threads: 1
Joined: Dec 2010
Reputation: 0
#3
12-22-2010, 06:08 AM
Sounds good.
"The universe seems neither benign nor hostile, merely indifferent."
- Carl Sagan
Website Find
Reply
Ezekiel000 Offline
Moderator
*****
Posts: 100
Threads: 5
Joined: Sep 2010
Reputation: 2
#4
02-15-2012, 09:48 PM (This post was last modified: 02-15-2012, 11:27 PM by Ezekiel000.)
This can be changed with this:
Code:
--- nightingale/components/property/src/sbPropertyManager.cpp~    2012-02-15 10:34:11.538437812 +0000
+++ nightingale/components/property/src/sbPropertyManager.cpp    2012-02-15 11:07:21.165597478 +0000
@@ -522,6 +522,10 @@
   NS_ENSURE_SUCCESS(rv, rv);

   //Sorting by artist will sort by artist->album->disc no->track no->track name
+  rv = artistSecondarySort->AppendProperty(NS_LITERAL_STRING(SB_PROPERTY_YEAR),
+                                         NS_LITERAL_STRING("a"));
+  NS_ENSURE_SUCCESS(rv, rv);
+
   rv = artistSecondarySort->AppendProperty(NS_LITERAL_STRING(SB_PROPERTY_ALBUMNAME),
                                          NS_LITERAL_STRING("a"));
   NS_ENSURE_SUCCESS(rv, rv);

And you then need to export your ratings with the ratingfile extension, turn off music folder monitoring, remove all music from your library then turn on music folder monitoring and import your ratings back in. I'm not sure why it can't resort without all this but it doesn't.
Find
Reply
Ezekiel000 Offline
Moderator
*****
Posts: 100
Threads: 5
Joined: Sep 2010
Reputation: 2
#5
03-07-2012, 03:17 AM
This is updated for the 1.11 branch:
Code:
--- nightingale/components/property/src/sbPropertyManager.cpp~    2012-02-15 10:34:11.538437812 +0000
+++ nightingale/components/property/src/sbPropertyManager.cpp    2012-02-15 11:07:21.165597478 +0000
@@ -567,7 +567,12 @@
   rv = artistSecondarySort->SetStrict(PR_FALSE);
   NS_ENSURE_SUCCESS(rv, rv);

-  //Sorting by artist will sort by artist->album->disc no->track no->track name
+  //Sorting by artist will sort by artist->year->album->disc no->track no->track name
+  rv = artistSecondarySort->AppendProperty(
+                              NS_LITERAL_STRING(SB_PROPERTY_YEAR),
+                              NS_LITERAL_STRING("a"));
+  NS_ENSURE_SUCCESS(rv, rv);
+
   rv = artistSecondarySort->AppendProperty(
                               NS_LITERAL_STRING(SB_PROPERTY_ALBUMNAME),
                               NS_LITERAL_STRING("a"));

And you then need follow the instructions above to rebuild your library.
Find
Reply
Ezekiel000 Offline
Moderator
*****
Posts: 100
Threads: 5
Joined: Sep 2010
Reputation: 2
#6
11-13-2012, 07:44 AM
No the method hasn't changed here's a link to the file in the github repository
http://github.com/nightingale-media-play...anager.cpp

You need to download the source code, modify the file above then compile the source.
Find
Reply
ilikenwf Offline
Developer/Project Manager
*******
Posts: 412
Threads: 22
Joined: Nov 2010
Reputation: 8
#7
11-13-2012, 04:01 PM
I'd rather it be an option you can set the ordering in...make it variable for the user, not a static default.
How to Build Nightingale | Nightingale on GitHub
Find
Reply
Ezekiel000 Offline
Moderator
*****
Posts: 100
Threads: 5
Joined: Sep 2010
Reputation: 2
#8
11-13-2012, 07:13 PM
Unfortunately my programming skills don't extend to adding it as an option to the gui, also I have no idea how I'd go about forcing ngale to rebuild the library if you turn the option on or off.
Find
Reply
GeekShadow Offline
Mozilla addict
******
Posts: 195
Threads: 25
Joined: Nov 2010
Reputation: 4
#9
11-14-2012, 12:41 AM
Sounds like a small project, If I got time I will look on how to make this an option.
Former Songbird contributor
Nightingale Community developer
Mozilla Reps
Website Find
Reply
ilikenwf Offline
Developer/Project Manager
*******
Posts: 412
Threads: 22
Joined: Nov 2010
Reputation: 8
#10
11-15-2012, 06:48 AM
You wouldn't build the lib, you'd just have a function that toggles between the options that the frontend can manipulate...
How to Build Nightingale | Nightingale on GitHub
Find
Reply
« Next Oldest | Next Newest »
Pages (2): 1 2 Next »


  • View a Printable Version
  • Subscribe to this thread
Forum Jump:


Users browsing this thread: 1 Guest(s)
  • Return to Top
  • Lite (Archive) Mode
  • RSS Syndication
Current time: 03-25-2023, 06:14 PM Powered By MyBB, © 2002-2023 MyBB Group.
Design By AliReza_Tofighi In WhiteCrow Software Group.
white outlined nightingale project logo

Nightingale is free!
It is an Open Source project released under the terms of the GNU General Public License v2 (GPL v2).
For more details, please read the license information.

Follow us!
f  g  t

Support
  • Community Forum
  • Official Blog
  • Add-ons
  • Wiki
  • Help Forum
Contribute
  • Developer's Center
  • Translate Nightingale
  • Source Code
  • Report a Bug
Ressources
  • Download Nightingale
Linear Mode
Threaded Mode